@@ -11,7 +11,7 @@ use Cwd  ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.60_03';
+	$VERSION = '0.60_04';
 }
 
 # Load early if in a forking environment and we have
@@ -57,6 +57,29 @@ sub my_data {
 		);
 }
 
+sub my_music {
+	my ($class) = @_;
+	require Mac::Files;
+	$class->_find_folder(
+		Mac::Files::kMusicDocumentsFolderType(),
+		);
+}
+
+sub my_pictures {
+	my ($class) = @_;
+	require Mac::Files;
+	$class->_find_folder(
+		Mac::Files::kPictureDocumentsFolderType(),
+		);
+}
+
+sub my_videos {
+	my ($class) = @_;
+	require Mac::Files;
+	$class->_find_folder(
+		Mac::Files::kMovieDocumentsFolderType(),
+		);
+}
 
 sub _find_folder {
 	my ($class, $name) = @_;
@@ -116,6 +139,32 @@ sub _to_user {
 
 1;
 
+=pod
+
+=head1 NAME
+
+File::HomeDir::Darwin - find your home and other directories, on Darwin (OS X)
+
+=head1 DESCRIPTION
+
+This module provides Darwin-specific implementations for determining
+common user directories.  In normal usage this module will always be
+used via L<File::HomeDir>.
+
+=head1 SYNOPSIS
+
+  use File::HomeDir;
+  
+  # Find directories for the current user
+  $home    = File::HomeDir->my_home;        # /Users/mylogin
+  $desktop = File::HomeDir->my_desktop;     # /Users/mylogin/Desktop
+  $docs    = File::HomeDir->my_documents;   # /Users/mylogin/Documents
+  $music   = File::HomeDir->my_music;       # /Users/mylogin/Music
+  $pics    = File::HomeDir->my_pictures;    # /Users/mylogin/Pictures
+  $videos  = File::HomeDir->my_videos;      # /Users/mylogin/Movies
+  $data    = File::HomeDir->my_data;        # /Users/mylogin/Library/Application Support
+   
+
 =head1 TODO
 
 =over 4
